@@ -1,9 +1,11 @@
 try:
     from normatrix.source.file_parser import CFileParse
     from normatrix.source.config import TypeLine
+    from normatrix.source.custom_regex import re_sub
 except ModuleNotFoundError:
     from normatrix.normatrix.source.file_parser import CFileParse
     from normatrix.normatrix.source.config import TypeLine
+    from normatrix.normatrix.source.custom_regex import re_sub
 
 import re
 
@@ -17,9 +19,9 @@ def check(context, file: CFileParse) -> (int, int):
         line = file.sub_parsedline[i]
         if line[0] == TypeLine.COMMENT:
             continue
-        ll = re.sub(".*?\*\/", '', line[1])
-        ll = re.sub("\/\*.*", '', ll)
-        ll = re.sub("//.*", '', ll)
+        ll = re_sub(".*?\*\/", '', line[1], timeout=0.1)
+        ll = re_sub("\/\*.*", '', ll, timeout=0.1)
+        ll = re_sub("//.*", '', ll, timeout=0.1)
         nb = ll.count(';')
         if nb > 1 and 'for' not in ll:
             list_error.append(
