@@ -1,9 +1,11 @@
 try:
     from normatrix.source.file_parser import CFileParse
     from normatrix.source.config import TypeLine
+    from normatrix.source.custom_regex import re_search, re_sub
 except ModuleNotFoundError:
     from normatrix.normatrix.source.file_parser import CFileParse
     from normatrix.normatrix.source.config import TypeLine
+    from normatrix.normatrix.source.custom_regex import re_search, re_sub
 
 import re
 
@@ -16,10 +18,10 @@ def check(context, file: CFileParse) -> (int, int, list):
     for i, line in enumerate(file.sub_parsedline):
         if line[0] == TypeLine.COMMENT:
             continue
-        ll = re.sub(".*?\*\/", '', line[1])
-        ll = re.sub("\/\*.*", '', ll)
-        ll = re.sub("//.*", '', ll)
-        m = re.search('(\[ )|( \])', ll)
+        ll = re_sub(".*?\*\/", '', line[1], timeout=0.1)
+        ll = re_sub("\/\*.*", '', ll, timeout=0.1)
+        ll = re_sub("//.*", '', ll, timeout=0.1)
+        m = re_search('(\[ )|( \])', ll, timeout=0.1)
         if m != None:
             list_error.append(
                     (i + 1, f"no space after [ or before ] ({line[1]})")
