@@ -1,5 +1,9 @@
 import re
 from enum import Enum
+try:
+    from normatrix.source.custom_regex import re_compile
+except ModuleNotFoundError:
+    from normatrix.normatrix.source.custom_regex import re_compile
 
 LIBC_BANNED_FUNC = [
         'printf',
@@ -55,25 +59,25 @@ class TypeLine(Enum):
 
 REG_TYPELINE = {
     TypeLine.COMMENT: [
-        re.compile("^( ){0,}?\/\*(.*?\n{0,}){0,}\*\/"),
-        re.compile("^( ){0,}?\/\/.*")
+        re_compile("^( ){0,}?\/\*(.*?\n{0,}){0,}\*\/"),
+        re_compile("^( ){0,}?\/\/.*")
     ],
     TypeLine.MACRO: [
-        re.compile("^ {0,}#\w{1,}.*")
+        re_compile("^ {0,}#\w{1,}.*")
     ],
     TypeLine.STRUCT: [
-        re.compile("^(typedef ){0,1}(struct )(\w{1,} ){0,1}{\n {4}\w{1,} \w{1,};(\n {4}\w{1,} \w{1,};){0,}\n}( \w{1,}){0,1};")
+        re_compile("^(typedef ){0,1}(struct )(\w{1,} ){0,1}{\n {4}\w{1,} \w{1,};(\n {4}\w{1,} \w{1,};){0,}\n}( \w{1,}){0,1};")
     ],
     TypeLine.ENUM: [
-        re.compile("^(typedef ){0,1}(enum )(\w{1,} ){0,1}{\n {4}\w{1,} \w{1,};(\n {4}\w{1,} \w{1,};){0,}\n}( \w{1,}){0,1};")
+        re_compile("^(typedef ){0,1}(enum )(\w{1,} ){0,1}{\n {4}\w{1,} \w{1,};(\n {4}\w{1,} \w{1,};){0,}\n}( \w{1,}){0,1};")
     ],
     TypeLine.GLOBAL: [
-        re.compile("^(static ){0,1}(const ){0,1}\w{1,} \*{0,}\w{1,}(\[[0-9]{0,}\]){0,1} = ((\w{0,})|({\n{0,1} {0,}\w{0,}(,\n{0,1} {0,}\w{0,}){0,})|)\n{0,1}}{0,1};")
+        re_compile("^(static ){0,1}(const ){0,1}\w{1,} \*{0,}\w{1,}(\[[0-9]{0,}\]){0,1} = ((\w{0,})|({\n{0,1} {0,}\w{0,}(,\n{0,1} {0,}\w{0,}){0,})|)\n{0,1}}{0,1};")
     ],
     TypeLine.FUNCTION: [
-        re.compile("((static )|(const )){0,}\w{1,}(\*){0,} (\*){0,}\w{1,}\(((void)|(\n{0,1}.*( *\w{1,}){1,}(\*){0,} (\*){0,}\w{1,}(\[[0-9]{0,}\]){0,}(, {0,1}\n{0,1}( *\w{1,})(\*){0,} (\*){0,}\w{1,}(\[\d{0,}\]){0,}){0,3})\n{0,1} {0,})\)\n{0,1} {0,1}{\n(.*\n)*?}")
+        re_compile("((static )|(const )){0,}\w{1,}(\*){0,} (\*){0,}\w{1,}\(((void)|(\n{0,1}.*( *\w{1,}){1,}(\*){0,} (\*){0,}\w{1,}(\[[0-9]{0,}\]){0,}(, {0,1}\n{0,1}( *\w{1,})(\*){0,} (\*){0,}\w{1,}(\[\d{0,}\]){0,}){0,3})\n{0,1} {0,})\)\n{0,1} {0,1}{\n(.*\n)*?}")
     ],
     TypeLine.FUNC_PROTO: [
-        re.compile("((static )|(const )){0,}\w{1,}(\*){0,} (\*){0,}\w{1,}\(((void)|(\n{0,1}.*( *\w{1,}){1,}(\*){0,} (\*){0,}\w{1,}(\[[0-9]{0,}\]){0,}(, {0,1}\n{0,1}( *\w{1,})(\*){0,} (\*){0,}\w{1,}(\[\d{0,}\]){0,}){0,3})\n{0,1} {0,})\);")
+        re_compile("((static )|(const )){0,}\w{1,}(\*){0,} (\*){0,}\w{1,}\(((void)|(\n{0,1}.*( *\w{1,}){1,}(\*){0,} (\*){0,}\w{1,}(\[[0-9]{0,}\]){0,}(, {0,1}\n{0,1}( *\w{1,})(\*){0,} (\*){0,}\w{1,}(\[\d{0,}\]){0,}){0,3})\n{0,1} {0,})\);")
     ]
 }
